==> knewstuff-5.91.0.tgz: lib/cmake/KF5NewStuff/KF5NewStuffTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::NewStuff" for configuration "Release"
set_property(TARGET KF5::NewStuff APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::NewStuff PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::KIOCore;KF5::KIOWidgets;KF5::Completion;KF5::I18n;KF5::ItemViews;KF5::IconThemes;Qt5::Qml;Qt5::Quick;KF5::TextWidgets"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5NewStuff.so.6.1"
  IMPORTED_SONAME_RELEASE "libKF5NewStuff.so.6.1"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::NewStuff )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::NewStuff "${_IMPORT_PREFIX}/lib/libKF5NewStuff.so.6.1" )

# Import target "KF5::NewStuffWidgets" for configuration "Release"
set_property(TARGET KF5::NewStuffWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::NewStuffWidgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::I18n"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5NewStuffWidgets.so.0.0"
  IMPORTED_SONAME_RELEASE "libKF5NewStuffWidgets.so.0.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS KF5::NewStuffWidgets )
list(APPEND _IMPORT_CHECK_FILES_FOR_KF5::NewStuffWidgets "${_IMPORT_PREFIX}/lib/libKF5NewStuffWidgets.so.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> knewstuff-5.98.0.tgz: lib/cmake/KF5NewStuff/KF5NewStuffTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "KF5::NewStuff" for configuration "Release"
set_property(TARGET KF5::NewStuff APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::NewStuff PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::KIOCore;KF5::KIOWidgets;KF5::Completion;KF5::I18n;KF5::ItemViews;KF5::IconThemes;Qt5::Qml;Qt5::Quick;KF5::TextWidgets"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5NewStuff.so.6.2"
  IMPORTED_SONAME_RELEASE "libKF5NewStuff.so.6.2"
  )

list(APPEND _cmake_import_check_targets KF5::NewStuff )
list(APPEND _cmake_import_check_files_for_KF5::NewStuff "${_IMPORT_PREFIX}/lib/libKF5NewStuff.so.6.2" )

# Import target "KF5::NewStuffWidgets" for configuration "Release"
set_property(TARGET KF5::NewStuffWidgets APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(KF5::NewStuffWidgets PROPERTIES
  IMPORTED_LINK_DEPENDENT_LIBRARIES_RELEASE "KF5::I18n"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libKF5NewStuffWidgets.so.0.0"
  IMPORTED_SONAME_RELEASE "libKF5NewStuffWidgets.so.0.0"
  )

list(APPEND _cmake_import_check_targets KF5::NewStuffWidgets )
list(APPEND _cmake_import_check_files_for_KF5::NewStuffWidgets "${_IMPORT_PREFIX}/lib/libKF5NewStuffWidgets.so.0.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
